@@ -1,6 +1,16 @@
-__version__ = "1.8.5"
+__version__ = "2.3.2"
 
 
+import os
+
+_dir = os.path.dirname(__file__)
+_camlibs = os.path.join(_dir, 'camlibs')
+if os.path.isdir(_camlibs):
+    os.environ['CAMLIBS'] = _camlibs
+_iolibs = os.path.join(_dir, 'iolibs')
+if os.path.isdir(_iolibs):
+    os.environ['IOLIBS'] = _iolibs
+
 class GPhoto2Error(Exception):
     """Exception raised by gphoto2 library errors
 
@@ -25,3 +35,5 @@ from gphoto2.port_log import *
 from gphoto2.result import *
 from gphoto2.version import *
 from gphoto2.widget import *
+
+__all__ = dir()
